function dd = DIVDIFF(x,f)
% dd = DIVDIFF(x,f)
%
% Interpolation nach dem Newton-Schema bei vorgegebenen Stützstellen-Vektor x,
% Funktionswerte-Vektor f gleicher Länge. 
%
% Das Programm liefert die dividierten Differenzen dd (wobei dd(1)=f[x(1)],
% dd(2)=f[x(1),x(2)],... dd(n)=f[x(1),x(2),...x(n)]) für die Newton-Darstellung
% des Interpolationspolynoms bei paarweise verschiedenen Stützstellen.
%
% -----------------------------------------------------------------------------
%
% Eingabe
% -------
% x         Stützstellenvektor
% f         zugehörige Funktionswerte
%
% -----------------------------------------------------------------------------
% 
% Ausgabe
% -------
% dd        Vektor der dividierten Differenzen

